using System;
using System.Drawing;
using MonoTouch.Foundation;
using MonoTouch.UIKit;
using Infragistics;
using System.Collections.Generic;

namespace CustomCell
{
	public partial class CustomCellViewController : UIViewController
	{

		IGGridViewDataSourceHelper ds;
		IGGridView grid;
		List<Data> data;
	
		static bool UserInterfaceIdiomIsPhone {
			get { return UIDevice.CurrentDevice.UserInterfaceIdiom == UIUserInterfaceIdiom.Phone; }
		}

		public CustomCellViewController ()
			: base ()
		{
		}
		public override void ViewDidLoad ()
		{
			base.ViewDidLoad ();

			this.View.BackgroundColor = UIColor.White;

			data = Data.generateData (150);

			grid = new IGGridView (new RectangleF (0, 0, this.View.Bounds.Size.Width , this.View.Bounds.Size.Height),
			                       IGGridViewStyle.IGGridViewStyleDefault);

			grid.AutoresizingMask = UIViewAutoresizing.FlexibleWidth | UIViewAutoresizing.FlexibleHeight;

			this.View.Add (grid);


			ds = new IGGridViewDataSourceHelper();
			ds.ColumnDefinitions.AddObjects(new NSObject[]{new IGGridViewColumnDefinition("Identifier"), new DateColumn("Date"){Editiable = true}, new IGGridViewColumnDefinition("Name")});
			ds.AllowEditing = true;
			ds.Data = data.ToArray ();

			grid.DataSource = ds;

		}


	}

	public class BaseColumn : IGGridViewColumnDefinition
	{
		string _fieldKey;
		public override string FieldKey {
			get {
				return _fieldKey;
			}
		}

		public BaseColumn(string key):base()
		{
			_fieldKey = key;
		}
	}

	public class DateColumn : BaseColumn
	{
		UITextField _editor;
		public DateColumn(string key):base(key)
		{
			_editor = new UITextField ();
		}

		public override IGGridViewCell CreateCell (IGGridView gridView, IGCellPath path, IGGridViewDataSourceHelper dataSource)
		{
			DateCell cell = (DateCell)gridView.DequeueReusableCell ("DateCell");

			if (cell == null)
				cell = new DateCell ("DateCell");

			DateTime dt = (NSDate)dataSource.ResolveDataValueForCell (path);

			cell.TextLabel.Text = dt.ToShortDateString ();

		


			return cell;
		}


		public override void DisplayEditor (IGGridView gridView, IGCellPath path, IGGridViewDataSourceHelper dataSource)
		{

			DateCell cell = (DateCell)gridView.ResolveCellForPath (path);

			gridView.RegisterKeyboard (cell);

			_editor.Bounds = new RectangleF(0, 0, cell.TextLabel.Bounds.Size.Width, cell.TextLabel.Bounds.Size.Height);
			_editor.Center = cell.TextLabel.Center;
			_editor.TextAlignment = cell.TextLabel.TextAlignment;

			_editor.Text = cell.TextLabel.Text;

			cell.Superview.AddSubview(_editor);
			_editor.Superview.SendSubviewToBack (_editor);
			_editor.BecomeFirstResponder ();
		
	
			UIView.Transition (cell.TextLabel, _editor, dataSource.EditingTransitionDuration, dataSource.EditingStartTransitionOptions, null);

		}

		public override void RemoveEditor (IGGridView gridView, IGCellPath path, IGGridViewDataSourceHelper dataSource, bool cellVisible, bool anotherCellEnteringEditMode)
		{
			gridView.UnregisterKeyboard (!anotherCellEnteringEditMode);

			DateCell cell = (DateCell)gridView.ResolveCellForPath (path);

			NSObject obj = dataSource.ResolveDataObjectForRow (path);
			this.SetTextOnCellForDataSource (_editor.Text, cell, dataSource);

			DateTime dt = DateTime.Parse (cell.TextLabel.Text);

			obj.SetValueForKey ((NSDate)dt, new NSString(this.FieldKey));


			UIView.Transition (_editor, cell.TextLabel, (cellVisible)? dataSource.EditingTransitionDuration : 0, dataSource.EditingEndTransitionOptions, null);
		}
	}


	public class DateCell :IGGridViewCell
	{
		public DateCell(string identifier):base(identifier)
		{

		}
	

	}
	
}

